@@ -114,9 +114,9 @@ def basic_metadata_tweets_extracted (data_tweets, node_list):
     
     extract_profiles =[]
     tweets_profiles =  list(df_basic_metadata_tweets_extracted["screen_name"])
-    for profile in tweets_profiles:
-        for profile not in node_list:
-          extract_profiles.append(profile)
+    for item in node_list:
+      if item not in tweets_profiles:
+        extract_profiles.append(item)
           
     return extract_profiles, df_basic_metadata_tweets_extracted
 
@@ -400,7 +400,101 @@ def graph_json_values(df_graph, df_algComu):
             })
       
     return json.dumps(data)
-    
+
+def simple_user_timeline_extraction(node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups=1,save_by=300):
+    # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
+    profile_iter = save_by
+    k=0
+    auth = tweepy.OAuthHandler(consumerKey[0], consumerSecret[0])
+    auth.set_access_token(accessToken[0], accessTokenSecret[0])
+    api = tweepy.API(auth)
+    nc= 0
+    ultima = 0
+    origen1 = time.time()
+    while ((k<= (len(node_list)+profile_iter)) & (ultima !=2) ):
+      tweets_user=[]
+      list_users_noInfo = []
+      origen2 = time.time()
+      i=0
+      if ((len(node_list)>= k) & ((len(node_list)-profile_iter) <=k)):
+        node_list1 = node_list[k:len(node_list)]
+        ultima = 1
+      else:
+        node_list1 = node_list[k:k+profile_iter]
+      while(i <(len(node_list1))):         
+        pri = 0
+        itera=0
+        max_id=""
+        intentos = 0
+        while itera != n_groups:
+          try:
+            if pri ==0:
+              user=api.user_timeline(node_list1[i], count=1,tweet_mode="extended")      
+              tweets_user.append(user)
+              max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
+              pri=1
+              itera = itera+1
+            else:
+              user=api.user_timeline(node_list1[i], count=1,tweet_mode="extended", max_id=max_id)
+              tweets_user.append(user)
+              max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
+              itera = itera+1
+              intentos=0 # Para si justo es el primero el que no se puede extraer y no es problema de agotar claves
+          except:
+            nc = nc+1
+            n_clave = len(consumerKey)
+            if(nc == n_clave):
+              nc= 0
+            auth = tweepy.OAuthHandler(consumerKey[nc], consumerSecret[nc])
+            auth.set_access_token(accessToken[nc], accessTokenSecret[nc])
+            api = tweepy.API(auth)
+            intentos = intentos + 1
+            if(intentos == 2):         
+              list_users_noInfo.append(node_list1[i])
+              intentos = 0
+              itera=n_groups
+        i = i+1       
+      destino2 = time.time()
+      aux=[]
+      for i in range( len(tweets_user)):
+        for j in range(len(tweets_user[i])):          
+            aux.append(tweets_user[i][j]._json)     
+      if(len(aux) != 0):  
+        df = pd.DataFrame(aux)
+        print(df.dtypes)
+        df = df.rename(columns = {"created_at": "created_at_tw"})
+        df= df.rename(columns = {"lang": "lang_tw"})
+        df = pd.concat([df.drop(['user'], axis=1), df['user'].apply(pd.Series)], axis=1)
+        df2 = df.rename(columns={"followers_count": "followers",
+                              "friends_count": "followees",
+                              "retweet_count": "retweets",
+                              "favorite_count": "favorites",
+                              "favourites_count": "favorites_count",
+                              "full_text": "text"})
+        if path.exists(os.path.join(filepath,filename+".csv")):
+          df2.to_csv(path_or_buf =os.path.join(filepath,filename+".csv"),mode="a", index=False, header=False)
+        else:
+          df2.to_csv(path_or_buf = os.path.join(filepath,filename+".csv"),index=False)         
+        if len(list_users_noInfo) !=0:
+          nodes = pd.DataFrame()
+          nodes["nodos"] = list_users_noInfo
+          if path.exists(os.path.join(filepath,"node_without_",filename+".csv")):
+            nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename+".csv"), mode ="a",index=False, header=False)          
+          else:
+             nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename+".csv"), index=False)
+        k = k+profile_iter        
+        if ultima ==1:          
+          ultima =2
+      else:
+        print("Repetimos")
+    print("Lista de usuarios sin metadata")
+    print(list_users_noInfo)
+    destino1 = time.time()
+    return df2, list_users_noInfo
+
+
+
+
 def user_timeline_extraction(node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups=1,save_by=300):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
     profile_iter = save_by
